@@ -1,28 +1,23 @@
 import itertools
 import operator
-import logging
+import warnings
 
 import numpy as np
+from astropy import units as u
 from astropy.modeling import fitting, Model, models
 from astropy.table import QTable
 from scipy.signal import convolve
 
-
-import astropy.units as u
-
 from ..spectra.spectral_region import SpectralRegion
 from ..spectra.spectrum1d import Spectrum1D
 from ..utils import QuantityModel
 from ..analysis import fwhm, gaussian_sigma_width, centroid, warn_continuum_below_threshold
-from ..manipulation import extract_region, noise_region_uncertainty
+from ..manipulation import extract_region
 from ..manipulation.utils import excise_regions
 
 __all__ = ['find_lines_threshold', 'find_lines_derivative', 'fit_lines',
            'estimate_line_parameters']
 
-log = logging.getLogger(__name__)
-
-
 # Define the initial estimators. This are the default methods to use to
 # estimate astropy model parameters. This is based on only a small subset of
 # the astropy models but it was determined that this is a decent start as most
@@ -386,8 +381,8 @@ def _fit_lines(spectrum, model, fitter=fitting.LevMarLSQFitter(),
             if uncerts is not None:
                 weights = uncerts.array ** -1
             else:
-                log.warning("Uncertainty values are not defined, but are "
-                                "trying to be used in model fitting.")
+                warnings.warn("Uncertainty values are not defined, but are "
+                              "trying to be used in model fitting.")
         else:
             raise ValueError("Unrecognized value `%s` in keyword argument.",
                              weights)
@@ -499,6 +494,7 @@ def _fit_lines(spectrum, model, fitter=fitting.LevMarLSQFitter(),
 
     return fit_model
 
+
 def _convert(quantity, dispersion_unit, dispersion, flux_unit):
     """
     Convert the quantity to the spectrum's units, and then we will use
