@@ -1,5 +1,5 @@
+import warnings
 from copy import deepcopy
-import logging
 
 import numpy as np
 from astropy import units as u
@@ -10,13 +10,11 @@ from .spectral_axis import SpectralAxis
 from .spectrum_mixin import OneDSpectrumMixin
 from .spectral_region import SpectralRegion
 from ..utils.wcs_utils import gwcs_from_array
-from astropy.coordinates import SpectralCoord
+
 from ndcube import NDCube
 
 __all__ = ['Spectrum1D']
 
-log = logging.getLogger(__name__)
-
 
 class Spectrum1D(OneDSpectrumMixin, NDCube, NDIOMixin, NDArithmeticMixin):
     """
@@ -138,7 +136,7 @@ class Spectrum1D(OneDSpectrumMixin, NDCube, NDIOMixin, NDArithmeticMixin):
         # a single float, int, or array object, just go ahead and ignore wcs
         # requirements
         if (not isinstance(flux, u.Quantity) or isinstance(flux, float)
-            or isinstance(flux, int)) and np.ndim(flux) == 0:
+                or isinstance(flux, int)) and np.ndim(flux) == 0:
 
             super(Spectrum1D, self).__init__(data=flux, wcs=wcs, **kwargs)
             return
@@ -156,9 +154,8 @@ class Spectrum1D(OneDSpectrumMixin, NDCube, NDIOMixin, NDArithmeticMixin):
                 rest_value = None
         else:
             if not isinstance(rest_value, u.Quantity):
-                log.info("No unit information provided with rest value. "
-                             "Assuming units of spectral axis ('%s').",
-                             spectral_axis.unit)
+                warnings.warn("No unit information provided with rest value. "
+                              f"Assuming units of spectral axis ('{spectral_axis.unit}').")
                 rest_value = u.Quantity(rest_value, spectral_axis.unit)
             elif not rest_value.unit.is_equivalent(u.AA, equivalencies=u.spectral()):
                 raise u.UnitsError("Rest value must be "
@@ -202,8 +199,8 @@ class Spectrum1D(OneDSpectrumMixin, NDCube, NDIOMixin, NDArithmeticMixin):
                 # Due to FITS conventions, a WCS with spectral axis first corresponds
                 # to a flux array with spectral axis last.
                 if temp_axes[0] != 0:
-                    log.warning("Input WCS indicates that the spectral axis is not"
-                                " last. Reshaping arrays to put spectral axis last.")
+                    warnings.warn("Input WCS indicates that the spectral axis is not"
+                                  " last. Reshaping arrays to put spectral axis last.")
                     wcs = wcs.swapaxes(0, temp_axes[0])
                     if flux is not None:
                         flux = np.swapaxes(flux, len(flux.shape)-temp_axes[0]-1, -1)
@@ -226,7 +223,6 @@ class Spectrum1D(OneDSpectrumMixin, NDCube, NDIOMixin, NDArithmeticMixin):
                                                         len(kwargs["uncertainty"].shape) -
                                                         temp_axes[0]-1, -1)
 
-
         # Attempt to parse the spectral axis. If none is given, try instead to
         # parse a given wcs. This is put into a GWCS object to
         # then be used behind-the-scenes for all specutils operations.
@@ -265,13 +261,12 @@ class Spectrum1D(OneDSpectrumMixin, NDCube, NDIOMixin, NDArithmeticMixin):
         elif wcs is None:
             # If no spectral axis or wcs information is provided, initialize
             # with an empty gwcs based on the flux.
-            size = len(flux) if not flux.isscalar else 1
+            size = flux.shape[-1] if not flux.isscalar else 1
             wcs = gwcs_from_array(np.arange(size) * u.Unit(""))
 
         super().__init__(
             data=flux.value if isinstance(flux, u.Quantity) else flux,
-            wcs=wcs, **kwargs
-            )
+            wcs=wcs, **kwargs)
 
         # If no spectral_axis was provided, create a SpectralCoord based on
         # the WCS
@@ -364,16 +359,23 @@ class Spectrum1D(OneDSpectrumMixin, NDCube, NDIOMixin, NDArithmeticMixin):
                     # Drop the spectral axis slice and perform only the spatial part
                     return temp_spec[item[:-1]]
 
+            if "original_wcs" not in self.meta:
+                new_meta = deepcopy(self.meta)
+                new_meta["original_wcs"] = deepcopy(self.wcs)
+            else:
+                new_meta = deepcopy(self.meta)
+
             return self._copy(
                 flux=self.flux[item],
                 spectral_axis=self.spectral_axis[spec_item],
                 uncertainty=self.uncertainty[item]
                 if self.uncertainty is not None else None,
-                mask=self.mask[item] if self.mask is not None else None)
+                mask=self.mask[item] if self.mask is not None else None,
+                meta=new_meta, wcs=None)
 
         if not isinstance(item, slice):
             if isinstance(item, u.Quantity):
-                raise ValueError("Indexing on a single spectral axis values is not"
+                raise ValueError("Indexing on a single spectral axis value is not"
                                  " currently allowed, please use a slice.")
             # Handle tuple slice as input by NDCube crop method
             elif isinstance(item, tuple):
@@ -397,8 +399,14 @@ class Spectrum1D(OneDSpectrumMixin, NDCube, NDIOMixin, NDArithmeticMixin):
         #  we create a new ``Spectrum1D`` that includes the sliced spectral
         #  axis. This means that a new wcs object will be created with the
         #  appropriate unit translation handling.
-        return tmp_spec._copy(
-            spectral_axis=self.spectral_axis[item])
+        if "original_wcs" not in self.meta:
+            new_meta = deepcopy(self.meta)
+            new_meta["original_wcs"] = deepcopy(self.wcs)
+        else:
+            new_meta = deepcopy(self.meta)
+
+        return tmp_spec._copy(spectral_axis=self.spectral_axis[item], wcs=None,
+                              meta=new_meta)
 
     def _copy(self, **kwargs):
         """
@@ -520,7 +528,6 @@ class Spectrum1D(OneDSpectrumMixin, NDCube, NDIOMixin, NDArithmeticMixin):
     def sum(self, **kwargs):
         return self.collapse("sum", **kwargs)
 
-
     @NDCube.mask.setter
     def mask(self, value):
         # Impose stricter checks than the base NDData mask setter
